/* machines.h --
   Included file in the makefile that gets run through Cpp.  This file
   tells which machines have what features based on the unique machine
   identifier present in Cpp. */

/* **************************************************************** */
/*                                                                  */
/*                Global Assumptions (true for most systems).       */
/*                                                                  */
/* **************************************************************** */

/* We make some global assumptions here.  This can be #undef'ed in
   various machine specific entries. */

/* If this file is being processed with Gcc, then the user has Gcc. */
#if defined (__GNUC__)
#  if !defined (HAVE_GCC)
#    define HAVE_GCC
#  endif /* HAVE_GCC */
#endif /* __GNUC__ */

/* Assume that all machines have the getwd () system call.  We unset it
   for USG systems. */
#define HAVE_GETWD

/* Most (but not all) systems have a good, working version of dup2 ().
   For systems that don't have the call (HP/UX), and for systems
   that don't set the open-on-exec flag for the dup'ed file descriptors,
   (Sequents running Dynix, Ultrix), #undef HAVE_DUP2 in the machine
   description. */
#define HAVE_DUP2

/* Every machine that has Gcc has alloca as a builtin in Gcc.  If you are
   compiling Bash without Gcc, then you must have alloca in a library,
   in your C compiler, or be able to assemble or compile the alloca source
   that we ship with Bash. */
#define HAVE_ALLOCA

/* We like most machines to use the GNU Malloc routines supplied in the
   source code because they provide high quality error checking.  On
   some machines, our malloc () cannot be used (because of library
   conflicts, for example), and for those, you should specifically
   #undef USE_GNU_MALLOC in the machine description. */
#define USE_GNU_MALLOC

/* **************************************************************** */
/*								    */
/*			Sun Miscrosystems Machines      	    */
/*								    */
/* **************************************************************** */

#if defined (sun)

/* We aren't currently using GNU Malloc on Suns because of a bug in Sun's
   YP which bites us when Sun free ()'s an already free ()'ed address.
   When Sun fixes their YP, we can start using our winning malloc again. */
#  undef USE_GNU_MALLOC

/* Most Sun systems have signal handler functions that are void. */
#  define VOID_SIGHANDLER

#  if defined (mc68010)
#    define sun2
#  endif
#  if defined (mc68020)
#    define sun3
#  endif
#  if defined (sparc)
#    define sun4
#  endif
#  if defined (i386)
#    define Sun386i
#    undef i386
#  endif
#if defined (HAVE_SHARED_LIBS)
#  define M_OS SunOS4
#else
#  if !defined (sparc)
#     undef VOID_SIGHANDLER
#  endif
#  define M_OS SunOS3
#endif
#endif /* sun */

/* ************************ */
/*			    */
/*	    Sun2	    */
/*			    */
/* ************************ */
#if defined (sun2)
#define M_MACHINE "sun2"
#define HAVE_SIGLIST
#define HAVE_SETLINEBUF
#define HAVE_VPRINTF
#define HAVE_MULTIPLE_GROUPS
#endif /* sun2 */

/* ************************ */
/*			    */
/*	    Sun3	    */
/*			    */
/* ************************ */
#if defined (sun3)
#define M_MACHINE "sun3"
#define HAVE_SIGLIST
#define HAVE_SETLINEBUF
#define HAVE_VPRINTF
#define HAVE_MULTIPLE_GROUPS
#endif /* sun3 */

/* ************************ */
/*			    */
/*	    Sparc	    */
/*			    */
/* ************************ */
#if defined (sun4)
#define M_MACHINE "sparc"
#define HAVE_SIGLIST
#define HAVE_SETLINEBUF
#define HAVE_VPRINTF
#define HAVE_MULTIPLE_GROUPS
#endif /* sparc */

/* ************************ */
/*			    */
/*	    Sun386i	    */
/*			    */
/* ************************ */
#if defined (Sun386i)
#define M_MACHINE "Sun386i"
#define HAVE_SIGLIST
#define HAVE_SETLINEBUF
#define HAVE_VPRINTF
#define HAVE_MULTIPLE_GROUPS
#endif /* Sun386i */

/* **************************************************************** */
/*								    */
/*			DEC Machines (vax, decstations)   	    */
/*								    */
/* **************************************************************** */

/* ************************ */
/*			    */
/*	    Ultrix	    */
/*			    */
/* ************************ */
#if defined (ultrix)
#if defined (MIPSEL)
#  define M_MACHINE "MIPSEL"
#  if !defined (HAVE_GCC)
#    define SYSDEP_CFLAGS -Wf,-XNl3072
#  endif
#else
#  define M_MACHINE "vax"
#endif
#define M_OS Ultrix
#undef HAVE_DUP2
#define VOID_SIGHANDLER
#define HAVE_SIGLIST
#define HAVE_SETLINEBUF
#define HAVE_VPRINTF
#define HAVE_MULTIPLE_GROUPS
#endif /* ultrix */

/* ************************ */
/*			    */
/*	VAX 4.3 BSD	    */
/*			    */
/* ************************ */
#if defined (vax) && !defined (ultrix)
#define M_MACHINE "vax"
#define M_OS Bsd
#define HAVE_SETLINEBUF
#define HAVE_SIGLIST
#define HAVE_MULTIPLE_GROUPS
#endif /* vax && !ultrix */

/* ******************************** */
/*				    */
/*	   MIPS RISC/os		    */
/*				    */
/* ******************************** */

#if defined (mips) && !defined (ultrix) && !defined (sgi) && !defined (sony)

#if defined (MIPSEB)
#  define M_MACHINE "MIPSEB"
#else
#  if defined (MIPSEL)
#    define M_MACHINE "MIPSEL"
#  else
#    define M_MACHINE "mips"
#  endif /* MIPSEL */
#endif /* MIPSEB */

#define M_OS Bsd
#if !defined (HAVE_GCC)
#  define SYSDEP_CFLAGS -DOPENDIR_NOT_ROBUST
#else
#  define SYSDEP_CFLAGS -Wf,-XNl3072 -systype bsd43 -DOPENDIR_NOT_ROBUST
#endif /* !HAVE_GCC */
#define HAVE_SIGLIST
#define HAVE_SETLINEBUF
#define HAVE_VPRINTF
#define HAVE_MULTIPLE_GROUPS
/* This is actually present but unavailable in the BSD universe? */
#undef HAVE_UNISTD_H
#if !defined (HAVE_RESOURCE)
#  define HAVE_RESOURCE
#endif
#endif /* mips */

/* ************************ */
/*			    */
/*	  Pyramid	    */
/*			    */
/* ************************ */
#if defined (pyr)
#define M_MACHINE "Pyramid"
#define M_OS Bsd
#define HAVE_SIGLIST
#define HAVE_SETLINEBUF
/* We do have vfprinf and varargs, but I get an syntax error at line
   486 of make_cmd if I use them ?! */
/* #define HAVE_VPRINTF */
#define HAVE_MULTIPLE_GROUPS
#endif /* pyr */

/* ************************ */
/*			    */
/*	    IBMRT	    */
/*			    */
/* ************************ */
/* Notes:  Compiling with pcc seems to work better than compiling with
   the hc compiler.  I had problems when compiling with hc with alloca,
   even though the -ma flag was defined.  (bfox) */
#if defined (ibm032)
#define M_MACHINE "IBMRT"
#define M_OS Bsd
#define HAVE_SIGLIST
#define HAVE_SETLINEBUF
/* Some systems cannot find vprintf at load time. */
/* #define HAVE_VPRINTF */
/* Alloca requires either gcc or pcc with -ma in SYSDEP_CFLAGS. */
#if !defined (HAVE_GCC)
#  define SYSDEP_CFLAGS -ma
#endif
#define HAVE_MULTIPLE_GROUPS
#endif /* ibm032 */

/* ************************ */
/*			    */
/*	    i386	    */
/*			    */
/* ************************ */

/* Sequent Symmetry running Dynix (4.2 BSD) */

#if defined (i386) && defined (sequent)
#undef i386
/* Need to undef sequent so the subsequent section for the Balance doesn't
   catch it and redefine some build parameters */
#undef sequent
#define M_MACHINE "Symmetry"
#define M_OS Bsd
#define SYSDEP_CFLAGS -DCPCC
#undef HAVE_DUP2
#define HAVE_SETLINEBUF
#define HAVE_SIGLIST
#define HAVE_MULTIPLE_GROUPS
#endif /* i386 && sequent */

/* Generic 386 clone running Mach (4.3 BSD-compatible) */

#if defined (i386) && defined (MACH)
#undef i386
#define M_MACHINE "i386"
#define M_OS Bsd
#define HAVE_SETLINEBUF
#define HAVE_SIGLIST
#define HAVE_MULTIPLE_GROUPS
#endif /* i386 && MACH */

/* AIX/PS2 1.2 for the 386 */

#if defined (i386) && defined (aixpc)
#undef i386
#define M_MACHINE "i386"
#define M_OS AIX
#define HAVE_VPRINTF
#define VOID_SIGHANDLER
#define SYSDEP_CFLAGS -D_BSD
#define REQUIRED_LIBRARIES -lbsd
#define HAVE_MULTIPLE_GROUPS
#endif /* i386 && aix */

/* System V Release 4 on the 386 */

#if defined (i386) && defined (USGr4)
#undef i386
#define M_MACHINE "i386"
#define M_OS USG
#define HAVE_SIGLIST
#define HAVE_VPRINTF
#define VOID_SIGHANDLER
#undef HAVE_GETWD
/* Alloca requires either Gcc or cc with libucb.a */
#if !defined (HAVE_GCC)
#  define REQUIRED_LIBRARIES -lc /usr/ucblib/libucb.a
#endif /* !HAVE_GCC */
#define HAVE_MULTIPLE_GROUPS
#define SYSDEP_CFLAGS -DUSGr4
#endif /* i386 && USGr4 */

/* 386 box running Interactive Unix 2.2? */
#if defined (isc386)
#undef i386
#undef HAVE_ALLOCA
#define M_MACHINE "isc386"
#define M_OS USG
#undef HAVE_GETWD
#define HAVE_VPRINTF
#define VOID_SIGHANDLER

/* <sys/types.h> uses mode_t, but doesn't define it unless _POSIX_SOURCE
   is defined.  But when _POSIX_SOURCE is defined, <signal.h> tries to
   use pid_t without including <sys/types.h>!  What a mess.

   ISC's <sys/fcntl.h> doesn't want to define O_NDELAY if __STDC__ is
   defined.  Fix that, too.  */
#if defined (__STDC__) || defined (HAVE_GCC)
#  define SYSDEP_CFLAGS -DUSGr3 -Dmode_t="unsigned short" -DO_NDELAY=O_NONBLOCK
#else
#  define SYSDEP_CFLAGS -DUSGr3 -Dmode_t="unsigned short"
#endif /* __STDC__ || HAVE_GCC */

/* ISC's wait.h requires lots of POSIX junk.  Forget it. */
#undef HAVE_WAIT_H

/* libcposix.a contains putc, getc, fileno. */
#define REQUIRED_LIBRARIES -lcposix
#endif /* isc386 */

/* Assume a generic 386 running sys5r3 something */

#if defined (i386)
#undef i386
#define M_MACHINE "i386"
#define M_OS USG
#undef HAVE_GETWD
#define SYSDEP_CFLAGS -DUSGr3
#define HAVE_VPRINTF
#define VOID_SIGHANDLER
/* Alloca requires either Gcc or cc with libPW.a */
#if !defined (HAVE_GCC)
#  define REQUIRED_LIBRARIES -lPW
#endif /* !HAVE_GCC */
#endif /* i386 */

/* ************************ */
/*			    */
/* Gould 9000 - UTX/32 R2.1A */
/*			    */
/* ************************ */
#if defined (gould)		/* maybe should be GOULD_PN ? */
#define M_MACHINE "gould"
#define M_OS Bsd
#define HAVE_SIGLIST
#define HAVE_SETLINEBUF
#define HAVE_MULTIPLE_GROUPS
#endif /* gould */

/* ************************ */
/*			    */
/*	    NeXT	    */
/*			    */
/* ************************ */
#if defined (NeXT)
#define M_MACHINE "NeXT"
#define M_OS Bsd
#define HAVE_VPRINTF
#define HAVE_SIGLIST
#define HAVE_MULTIPLE_GROUPS
#define HAVE_STRERROR
#undef USE_GNU_MALLOC
#endif

/* ************************ */
/*			    */
/*	hp9000 4.3 BSD	    */
/*			    */
/* ************************ */
#if defined (hp9000) && !defined (hpux)
#define M_MACHINE "hp9000"
#define M_OS Bsd
#undef HAVE_ALLOCA
#define HAVE_SIGLIST
#define HAVE_SETLINEBUF
#define HAVE_MULTIPLE_GROUPS
#endif /* hp9000 && !hpux */

/* ************************ */
/*			    */
/*	    hpux	    */
/*			    */
/* ************************ */
#if defined (hpux)
#define M_MACHINE "hpux"

/* This is for 6.2+ systems with job control. */
#define M_OS HPUX
#define REQUIRED_LIBRARIES -lBSD

/* For HP-UX 7.0, we don't need the -lBSD. */
/* #undef REQUIRED_LIBRARIES */

/* For HP-UX systems before 6.2, we don't have job control. */
/* #undef M_OS */
/* #define M_OS USG */

#undef HAVE_DUP2
#define HAVE_VPRINTF
#define VOID_SIGHANDLER
#define HAVE_MULTIPLE_GROUPS
#define HAVE_STRERROR
#endif /* hpux */

/* ************************ */
/*			    */
/*	    Xenix286	    */
/*			    */
/* ************************ */
#if defined (Xenix286)
#define M_MACHINE "i286"
#define M_OS Xenix
#undef HAVE_ALLOCA
#define REQUIRED_LIBRARIES -lx
#endif

/* ************************ */
/*			    */
/*	    Xenix386	    */
/*			    */
/* ************************ */
#if defined (Xenix386)
#define M_MACHINE "i386"
#define M_OS Xenix
#undef HAVE_ALLOCA
#define ALLOCA_ASM x386-alloca.s
#define REQUIRED_LIBRARIES -lx
#endif

/* ************************ */
/*			    */
/*	    convex	    */
/*			    */
/* ************************ */
#if defined (convex)
#define M_MACHINE "convex"
#define M_OS Bsd
#undef HAVE_ALLOCA
#define HAVE_SETLINEBUF
#define HAVE_SIGLIST
#define HAVE_MULTIPLE_GROUPS
#endif /* convex */

/* ************************ */
/*			    */
/*	    Sony	    */
/*			    */
/* ************************ */
#if defined (sony)
#if defined (MIPSEB)
#define M_MACHINE "MIPSEB"
#else
#define M_MACHINE "sony"
#endif

#if defined (SYSTYPE_SYSV) || defined (USGr4)
#  define M_OS USG
#  undef HAVE_GETWD
#  define HAVE_VPRINTF
#  define VOID_SIGHANDLER
   /* Alloca requires either Gcc or cc with libucb.a. */
#  if !defined (HAVE_GCC)
#    define REQUIRED_LIBRARIES -lc /usr/ucblib/libucb.a
#  endif /* !HAVE_GCC */
#  if defined (MIPSEB)
#    if !defined (HAVE_GCC)
#      define SYSDEP_CFLAGS -Wf,XNl3072 -DUSGr4
#    else
#      define SYSDEP_CFLAGS -DUSGr4
#    endif /* HAVE_GCC */
#  endif /* MIPSEB */
#else
#  define M_OS Bsd
#endif /* SYSTYPE_SYSV */
#define HAVE_SIGLIST
#define HAVE_SETLINEBUF
#define HAVE_MULTIPLE_GROUPS
#endif /* sony */

/* ************************ */
/*			    */
/*	    AIX/RT	    */
/*			    */
/* ************************ */
#if defined (aix) && !defined (aixpc)
#define M_MACHINE "AIX"
#define M_OS Bsd
#undef HAVE_ALLOCA
#define HAVE_VPRINTF
#define HAVE_SIGLIST
#define VOID_SIGHANDLER
#define HAVE_MULTIPLE_GROUPS
#endif /* AIX */

/* **************************************** */
/*					    */
/*		IBM RISC 6000		    */
/*					    */
/* **************************************** */
#if defined (RISC6000) || defined (_IBMR2)
#define M_MACHINE "RISC6000"
#define M_OS USG
#undef HAVE_GETWD
#undef HAVE_ALLOCA
#define HAVE_SIGLIST
#define HAVE_SETLINEBUF
#define HAVE_VPRINTF
#define VOID_SIGHANDLER
#define USE_TERMCAP_EMULATION
#define HAVE_MULTIPLE_GROUPS
#undef USE_GNU_MALLOC
#endif /* RISC6000 */

/* **************************************** */
/*					    */
/*	u370 IBM AIX/370		    */
/*					    */
/* **************************************** */
#if defined (u370) || defined (_AIX370)
#define M_MACHINE "AIX370"
#define M_OS Bsd
#define REQUIRED_LIBRARIES -lbsd
#define HAVE_SETLINEBUF
#define HAVE_VPRINTF
#define SYSDEP_CFLAGS -D_BSD
#define HAVE_MULTIPLE_GROUPS
#undef USE_GNU_MALLOC
#endif /* u370 */

/* ************************ */
/*			    */
/*	    ATT 3B	    */
/*			    */
/* ************************ */
#if defined (att3b)
#define M_MACHINE "att3b"
#define M_OS USG
#undef HAVE_GETWD
#define HAVE_SIGLIST
#define HAVE_VPRINTF
#define VOID_SIGHANDLER
/* For an AT&T Unix before V.3 take out the -DUSGr3 */
#define SYSDEP_CFLAGS -DUSGr3
/* Alloca requires either Gcc or cc with libPW.a. */
#if !defined (HAVE_GCC)
#  define REQUIRED_LIBRARIES -lPW
#endif /* !HAVE_GCC */
#endif /* att3b */

/* ************************ */
/*			    */
/*	    ATT 386	    */
/*			    */
/* ************************ */
#if defined (att386)
#define M_MACHINE "att386"
#define M_OS USG
#undef HAVE_GETWD
/* Alloca requires either Gcc or cc with libPW.a. */
#if !defined (HAVE_GCC)
#  define REQUIRED_LIBRARIES -lPW
#endif /* HAVE_GCC */
#define HAVE_SIGLIST
#define HAVE_VPRINTF
#define VOID_SIGHANDLER
/* For an AT&T Unix before V.3 take out the -DUSGr3 */
#define SYSDEP_CFLAGS -DUSGr3
#endif /* att386 */

/* ************************ */
/*			    */
/*	    Encore	    */
/*			    */
/* ************************ */
#if defined (MULTIMAX)
#  if defined (n16)
#    define M_MACHINE "Multimax32k"
#  else
#    define M_MACHINE "Multimax"
#  endif /* n16 */
#  if defined (UMAXV)
#    define M_OS USG
#    define REQUIRED_LIBRARIES -lPW
#    define SYSDEP_CFLAGS -DUSGr3
#    define HAVE_VPRINTF
#    define USE_TERMCAP_EMULATION
#    define VOID_SIGHANDLER
#  else
#    if defined (CMU)
#      define M_OS Mach
#    else
#      define M_OX Bsd
#    endif /* CMU */
#    define HAVE_SIGLIST
#    define HAVE_STRERROR
#    define HAVE_SETLINEBUF
#  endif /* UMAXV */
#  define HAVE_MULTIPLE_GROUPS
#endif  /* MULTIMAX */

/* ******************************************** */
/*						*/
/*   Encore Series 91 (88K BCS w Job Control)	*/
/*						*/
/* ******************************************** */
#if defined (__m88k) && defined (__UMAXV__)
#define M_MACHINE "Gemini"
#define M_OS USG
#define REQUIRED_LIBRARIES -lPW
#define USE_TERMCAP_EMULATION
#define HAVE_VPRINTF
#define HAVE_MULTIPLE_GROUPS
#define VOID_SIGHANDLER
#define SYSDEP_CFLAGS -q ext=pcc -D_POSIX_JOB_CONTROL -D_POSIX_VERSION \
		      -Dmalloc=_malloc -Dfree=_free -Drealloc=_realloc
#endif  /* m88k */

/* ************************ */
/*			    */
/*	    clipper	    */
/*			    */
/* ************************ */
/* This is for the Orion 1/05 (A BSD 4.2 box based on a Clipper processor) */
#if defined (clipper)
#define M_MACHINE "clipper"
#define M_OS Bsd
#define HAVE_SETLINEBUF
#define HAVE_MULTIPLE_GROUPS
#endif  /* clipper */

/* ******************************** */
/*				    */
/*	   is68k(Omron luna)	    */
/*				    */
/* ******************************** */
#if defined (is68k)
#define M_MACHINE "is68k"
#define M_OS Bsd
#undef HAVE_ALLOCA
#define HAVE_SIGLIST
#define HAVE_SETLINEBUF
#define HAVE_MULTIPLE_GROUPS
#endif /* is68k */

/* **************************************** */
/*					    */
/*	    Apollo/SR10.2/BSD4.3	    */
/*					    */
/* **************************************** */
/* This is for the Apollo DN3500 running SR10.2 BSD4.3 */
#if defined (apollo)
#define M_MACHINE "apollo"
#define M_OS Bsd
#define HAVE_SIGLIST
#define HAVE_SETLINEBUF
#define HAVE_MULTIPLE_GROUPS
#endif  /* apollo */

/* **************************************** */
/*					    */
/*	SGI Iris/IRIX 3.3	    	    */
/*					    */
/* **************************************** */
#if defined (sgi)
#define M_MACHINE "sgi"
#define M_OS "USG"
#undef HAVE_GETWD
#undef HAVE_ALLOCA
#define HAVE_SIGLIST
#define HAVE_SETLINEBUF
#define HAVE_VPRINTF
#define REQUIRED_LIBRARIES -lsun
#if defined (mips)
#  if !defined (HAVE_GCC)
#    define SYSDEP_CFLAGS -real_frameptr -Wf,-XNl3072
#  endif
#endif /* mips */
#define HAVE_MULTIPLE_GROUPS
#define VOID_SIGHANDLER
#endif  /* sgi */

/* ************************ */
/*			    */
/*	DG AViiON	    */
/*			    */
/* ************************ */
/* This is for the DG AViioN box (runs DG/UX with both AT&T & BSD features.) */
#if defined (__DGUX__) || defined (DGUX)
#define M_MACHINE "AViiON"
#define M_OS USG
#undef HAVE_GETWD
/* DG/UX 4.x comes standard with gcc */
#define HAVE_GCC
#if !defined (DGUX)		/* Must define -DDGUX because cpp doesn't. */
#  define SYSDEP_CFLAGS \
	-D_M88KBCS_SOURCE -D_POSIX_SOURCE -D_POSIX_JOB_CONTROL -DDGUX
#else
#  define SYSDEP_CFLAGS \
	-D_M88KBCS_SOURCE -D_POSIX_SOURCE -D_POSIX_JOB_CONTROL
#endif /* !DGUX */
#define USE_TERMCAP_EMULATION
#define HAVE_MULTIPLE_GROUPS
#define VOID_SIGHANDLER
#undef USE_GNU_MALLOC
#endif

/* ************************ */
/*			    */
/*    Harris Night Hawk	    */
/*			    */
/* ************************ */
/* This is for the Harris Night Hawk family. */
#if defined (_CX_UX)
#if defined (_M88K)
# define M_MACHINE "nh4000"
#else
#  if defined (hcx)
#    define M_MACHINE "nh2000"
#  else
#    if defined (gcx)
#      define M_MACHINE "nh3000"
#    endif
#  endif
#endif
#define M_OS USG
#define SYSDEP_CFLAGS -g -Xa -v -Dgetwd=bash_getwd -D_POSIX_SOURCE -D_POSIX_JOB_CONTROL
#define USE_TERMCAP_EMULATION
#define HAVE_VPRINTF
#define HAVE_MULTIPLE_GROUPS
#define VOID_SIGHANDLER
#undef USE_GNU_MALLOC
#undef HAVE_GETWD
#endif

/* **************************************** */
/*					    */
/*	    	Tektronix	    	    */
/*					    */
/* **************************************** */
/* These are unproven as yet. */
#if defined (Tek4132)
#define M_MACHINE "Tek4132"
#define M_OS Bsd
#define HAVE_SIGLIST
#define HAVE_SETLINEBUF
#define HAVE_MULTIPLE_GROUPS
#endif /* Tek4132 */

#if defined (Tek4300)
#define M_MACHINE "Tek4300"
#define M_OS Bsd
#define HAVE_SIGLIST
#define HAVE_SETLINEBUF
#define HAVE_MULTIPLE_GROUPS
#endif /* Tek4300 */

/* ************************ */
/*			    */
/*     Sequent Balances     */
/*       (Dynix 3.x)	    */
/* ************************ */
#if defined (sequent)
#define M_MACHINE "Sequent"
#define M_OS Bsd
#undef HAVE_DUP2
#define HAVE_SIGLIST
#define HAVE_SETLINEBUF
#define HAVE_MULTIPLE_GROUPS
#endif /* sequent */

/* ****************************************** */
/*					      */
/*    NCR Tower 32, System V Release 3	      */
/*					      */
/* ****************************************** */
#if defined (tower32)
#define M_MACHINE "tower32"
#define M_OS USG
#if !defined (HAVE_GCC)
#  define REQUIRED_LIBRARIES -lPW
   /* Disable stack/frame-pointer optimization, incompatible with alloca */
#  define SYSDEP_CFLAGS -DUSGr3 -W2,-aat
#else
#  define SYSDEP_CFLAGS -DUSGr3
#endif /* !HAVE_GCC */
#define HAVE_VPRINTF
#define USE_TERMCAP_EMULATION
#define VOID_SIGHANDLER
#undef HAVE_GETWD
#endif /* tower32 */

/* ************************ */
/*			    */
/*	  Stardent	    */
/*			    */
/* ************************ */
#if defined (stardent)
#define M_MACHINE "Stardent"
#define M_OS USG
#undef HAVE_GETWD
#undef HAVE_ALLOCA
#define HAVE_SIGLIST
#define USE_TERMCAP_EMULATION
#define VOID_SIGHANDLER
#endif /* stardent */

/* ************************ */
/*			    */
/*	Concurrent	    */
/*			    */
/* ************************ */
#if defined (concurrent)
/* Use the BSD universe (`universe ucb') */
#define M_MACHINE "Concurrent"
#define M_OS Bsd
#define HAVE_SIGLIST
#define HAVE_SETLINEBUF
#define HAVE_MULTIPLE_GROUPS
#endif /* concurrent */

/* ************************ */
/*			    */
/*    Ardent Titan OS v2.2  */
/*			    */
/* ************************ */
#if defined (ardent)
#define M_MACHINE "Ardent Titan"
#define M_OS Bsd
#define REQUIRED_LIBRARIES -43
#define HAVE_SIGLIST
#define HAVE_SETLINEBUF
#define HAVE_MULTIPLE_GROUPS
#define SYSDEP_CFLAGS -43 -w
#undef HAVE_ALLOCA
#undef USE_GNU_MALLOC
#endif /* ardent */


/* ************************ */
/*			    */
/*    Cadmus (tested once)  */
/*			    */
/* ************************ */
/* Port by bfox.  I apologize to the rest of the world for Cadmus. */
#if defined (cadmus) && !defined (M_MACHINE)
#define M_MACHINE "cadmus"
#define M_OS BrainDeath		/* By Far, the worst yet. */
#define SYSDEP_CFLAGS -DUSG
#define HAVE_VPRINTF
#define VOID_SIGHANDLER
#define USE_TERMCAP_EMULATION
#undef HAVE_GETWD
#undef HAVE_ALLOCA
#endif  /* cadmus */

/* **************************************************************** */
/*								    */
/*			Generic Entry   			    */
/*								    */
/* **************************************************************** */

/* Use this entry for your machine if it isn't represented here.  It
   is based on a Vax running Bsd. */

#if !defined (M_MACHINE)
#define UNKNOWN_MACHINE
#endif

#ifdef UNKNOWN_MACHINE
#define M_MACHINE "UNKNOWN_MACHINE"
#define M_OS UNKNOWN_OS

/* Required libraries for building on this system. */
#define REQUIRED_LIBRARIES

/* Define HAVE_SIGLIST if your system has sys_siglist[]. */
#define HAVE_SIGLIST

/* Undef HAVE_ALLOCA if you are not using Gcc, and neither your library
   nor compiler has a version of alloca ().  In that case, we will use
   our version of alloca () in alloca.c */
/* #undef HAVE_ALLOCA

/* Define USE_GNU_MALLOC if you want to use the debugging version
   of malloc ().  We like this on by default. */
#if !defined (USE_GNU_MALLOC)
#  define USE_GNU_MALLOC
#endif /* USE_GNU_MALLOC */

/* Define USE_GNU_TERMCAP if you want to use the GNU termcap library
   instead of your system termcap library. */
/* #define USE_GNU_TERMCAP */

/* Define HAVE_SETLINEBUF if your machine has the setlinebuf ()
   stream library call.  Otherwise, setvbuf () will be used.  If
   neither of them work, you can edit in your own buffer control
   based upon your machines capabilities. */
#define HAVE_SETLINEBUF

/* Define HAVE_VPRINTF if your machines has the vprintf () library
   call.  Otherwise, printf will be used.  */
#define HAVE_VPRINTF

/* Define HAVE_MULTIPLE_GROUPS if your OS allows you to be in multiple
   groups simultaneously and supports the `getgroups' system call. */
/* #define HAVE_MULTIPLE_GROUPS */

/* Define SYSDEP_CFLAGS to be the flags to cc that make your compiler
   work.  For example, `-ma' on the RT makes alloca () work. */
#define SYSDEP_CFLAGS

/* Define HAVE_STRERROR if your system supplies a definition for strerror ()
   in the C library, or a macro in a header file. */
/* #define HAVE_STRERROR */

/* If your system does not supply /usr/lib/libtermcap.a, but includes
   the termcap routines as a part of the curses library, then define
   this.  This is the case on some System V machines. */
/* #define USE_TERMCAP_EMULATION */

/* Define VOID_SIGHANDLER if your system's signal () returns a pointer to
   a function returning void. */
/* #define VOID_SIGHANDLER */

#endif  /* UNKNOWN_MACHINE */
